Developer Documentation
=======================

Contributing to Scitacean
-------------------------

Contributions, bug reports, and ideas are always welcome.

TODO


.. toctree::
   :maxdepth: 2

   getting-started
   coding-conventions
   dependency-management
   testing
